# Generated by roxygen2: do not edit by hand

S3method(predict,cal_beta)
S3method(predict,cal_cv)
S3method(predict,cal_dirichlet)
S3method(predict,cal_histogram)
S3method(predict,cal_isotonic)
S3method(predict,cal_ovr)
S3method(predict,cal_platt)
S3method(predict,cal_temperature)
S3method(predict,cal_vector_scaling)
S3method(print,cal_ci)
S3method(print,cal_test)
S3method(print,calibrator)
S3method(summary,calibrator)
export(ace)
export(cal_beta)
export(cal_ci)
export(cal_cv)
export(cal_dirichlet)
export(cal_histogram)
export(cal_isotonic)
export(cal_ovr)
export(cal_platt)
export(cal_temperature)
export(cal_test)
export(cal_vector_scaling)
export(ece)
export(inv_logit)
export(logit)
export(mce)
export(mmce)
export(reliability_diagram)
export(skce)
